import React from 'react';
import styled from 'styled-components/native';
import palette from '../static/palette';

export interface AppButtonProps {
  width?: number;
  height?: number;
  backgroundColor?: string;
  color?: string;
  text?: string;
  disabled?: boolean;
  onPress?: () => void;
}

const AppButton = styled.TouchableOpacity<AppButtonProps>`
  display: flex;
  justify-content: center;
  align-items: center;
  width: ${(props) => props.width}px;
  height: ${(props) => props.height}px;
  color: ${(props) => props.color};
  background-color: ${(props) => (props.disabled ? palette.base.gray350 : props.backgroundColor)};
  border-radius: 4px;
`;

const Text = styled.Text`
  font-weight: bold;
  font-size: 16px;
  line-height: 16px;
  text-align: center;
  letter-spacing: -0.5px;
  color: ${palette.base.white};
`;

const Button = ({
  width = 360,
  height = 52,
  text = 'Button',
  color = palette.base.white,
  backgroundColor = palette.point.red_getcha,
  disabled = false,
  onPress = () => {},
}: AppButtonProps): JSX.Element => (
  <AppButton
    disabled={disabled}
    width={width}
    height={height}
    color={color}
    backgroundColor={backgroundColor}
    onPress={onPress}
  >
    <Text>{text}</Text>
  </AppButton>
);

export default Button;
